//
// ETSI (European Telecommunications Standards Institute, referred to as ETSI)
// ARF - ETSI ISG Augmented Reality Framework (ISG ARF)
// (C) 2022
//
// Development "World Storage", data management, authoring tools
//
// Authors:
// - Sylvain Renault (Fraunhofer HHI)
// 
// Date: Feb. 2022
//

#define USING_OPENAPI_GENERATOR // alt. is Swagger

using System.IO;
using System.Collections.Generic;
using UnityEngine;

#if USING_OPENAPI_GENERATOR
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Model;
#else
using IO.Swagger.Api;
using IO.Swagger.Model;
#endif

#if UNITY_EDITOR
namespace ETSI.ARF.WorldStorage.REST
{
    public class TrackableRequest
    {
        static public void AddTrackable(WorldStorageServer ws, Trackable trackable)
        {
            Debug.Log("Posting Add Trackable to Server");
            TrackablesApi api = new TrackablesApi(ws.URI);
            string result = api.AddTrackable(trackable);
            Debug.Log(result);
        }

        static public List<Trackable> GetAllTrackables(WorldStorageServer ws)
        {
            TrackablesApi api = new TrackablesApi(ws.URI);
            List<Trackable> result = api.GetTrackables();
            return result;
        }

        static public Trackable GetTrackable(WorldStorageServer ws, string uuid)
        {
            System.Guid _uuid = System.Guid.Parse(uuid);
            TrackablesApi api = new TrackablesApi(ws.URI);
            Trackable result = api.GetTrackableById(_uuid);
            return result;
        }

        static public void DeleteTrackable(WorldStorageServer ws, string uuid)
        {
            System.Guid _uuid = System.Guid.Parse(uuid);
            TrackablesApi api = new TrackablesApi(ws.URI);
            api.DeleteTrackable(_uuid);
        }
    }
}
#endif