//
// ETSI (European Telecommunications Standards Institute, referred to as ETSI)
// ARF - ETSI ISG Augmented Reality Framework (ISG ARF)
// (C) 2022
//
// Development "World Storage", data management, authoring tools
//
// Authors:
// - Sylvain Renault (Fraunhofer HHI)
// 
// Date: Feb. 2022
//

#define USING_OPENAPI_GENERATOR // alt. is Swagger

using System.IO;
using System.Collections.Generic;
using UnityEngine;

#if USING_OPENAPI_GENERATOR
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Model;
#else
using IO.Swagger.Api;
using IO.Swagger.Model;
#endif

#if UNITY_EDITOR
namespace ETSI.ARF.WorldStorage.REST
{
    public class WorldAnchorRequest
    {
        static public void AddWorldAnchor(WorldStorageServer ws, WorldAnchor anchor)
        {
            Debug.Log("Posting Add World Anchor to Server");
            WorldAnchorsApi api = new WorldAnchorsApi(ws.URI);
            string result = api.AddWorldAnchor(anchor);
            Debug.Log(result);
        }

        static public List<WorldAnchor> GetAllWorldAnchors(WorldStorageServer ws)
        {
            WorldAnchorsApi api = new WorldAnchorsApi(ws.URI);
            List<WorldAnchor> result = api.GetWorldAnchors();
            return result;
        }

        static public WorldAnchor GetWorldAnchor(WorldStorageServer ws, string uuid)
        {
            System.Guid _uuid = System.Guid.Parse(uuid);
            WorldAnchorsApi api = new WorldAnchorsApi(ws.URI);
            WorldAnchor result = api.GetWorldAnchorById(_uuid);
            return result;
        }

        static public void DeleteWorldAnchor(WorldStorageServer ws, string uuid)
        {
            System.Guid _uuid = System.Guid.Parse(uuid);
            WorldAnchorsApi api = new WorldAnchorsApi(ws.URI);
            api.DeleteWorldAnchor(_uuid);
        }
    }
}
#endif