//
// ETSI (European Telecommunications Standards Institute, referred to as ETSI)
// ARF - ETSI ISG Augmented Reality Framework (ISG ARF)
// (C) 2022
//
// Development "World Storage", data management, authoring tools
//
// Authors:
// - Sylvain Renault (Fraunhofer HHI)
// 
// Date: April 2022
//

using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using ETSI.ARF.WorldStorage;

public class WorldStorageInfo : MonoBehaviour
{
    public WorldStorageServer worldStorageServer;

    public bool isServerAlive()
    {
        if (worldStorageServer == null) return false;
        return !string.IsNullOrEmpty(ETSI.ARF.WorldStorage.REST.AdminRequest.Ping(worldStorageServer));
    }

    public string GetServerState()
    {
        if (worldStorageServer == null) return "No Server Defined!";
        return ETSI.ARF.WorldStorage.REST.AdminRequest.GetAdminInfo(worldStorageServer);
    }

    public string GetAPIVersion()
    {
        if (worldStorageServer == null) return "Unknown Version!";
        return ETSI.ARF.WorldStorage.REST.AdminRequest.GetVersion(worldStorageServer);
    }
}
